# SPDX-License-Identifier: Apache-2.0.
# Copyright (c) 2024 - 2025 Waldiez and contributors.
"""
Check for rpds-py on Windows ARM64.

Since we cannot use direct git dependency on `rpds-py` in `pyproject.toml`,
let's check it here.

NOTE: We should regularly check if this is still needed.
"""
# "rpds-py @ git+https://github.com/crate-py/rpds.git@v0.24.0 ;
# sys_platform == "win32" and platform_machine == "arm64"",
# "rpds-py @ git+https://github.com/crate-py/rpds.git@v0.24.0 ;
# sys_platform == "win32" and platform_machine == "ARM64"",
# "rpds-py @ git+https://github.com/crate-py/rpds.git@v0.24.0 ;
# sys_platform == "win32" and platform_machine == "aarch64"",
# "rpds-py @ git+https://github.com/crate-py/rpds.git@v0.24.0 ;
# sys_platform == "win32" and platform_machine == "AARCH64"",



# SPDX-License-Identifier: Apache-2.0.
# Copyright (c) 2024 - 2025 Waldiez and contributors.
# pylint: skip-file
# isort: skip_file
# flake8: noqa: E501,E402
"""Waldiez-runner extra typer commands for CLI."""

from typing import Any, Callable

import typer
from typer.models import CommandInfo

HAVE_RUNNER = False
runner_app: Callable[..., Any] | None = None

try:
    from waldiez_runner.cli import run  # type: ignore[unused-ignore, import-not-found, import-untyped]

    runner_app = run

    HAVE_RUNNER = True
except BaseException:
    pass


def add_runner_cli(app: typer.Typer) -> None:
    """Add runner command to the app if available.

    Parameters
    ----------
    app : typer.Typer
        The Typer app to add the runner command to.
    """
    if HAVE_RUNNER:
        app.registered_commands.append(
            CommandInfo(name="serve", callback=runner_app)
        )



# SPDX-License-Identifier: Apache-2.0.
# Copyright (c) 2024 - 2025 Waldiez and contributors.
"""Waldiez package."""

from .exporter import WaldiezExporter
from .models import Waldiez
from .runner import WaldiezRunner
from .utils import check_conflicts, check_flaml_warnings

# flake8: noqa: F401
# pylint: disable=import-error,line-too-long
# pyright: reportMissingImports=false
try:
    from ._version import (  # type: ignore[unused-ignore, unused-import, import-not-found, import-untyped]  # noqa
        __version__,
    )
except ImportError:  # pragma: no cover
    # Fallback when using the package in dev mode without installing
    # in editable mode with pip. It is highly recommended to install
    # the package from a stable release or in editable mode:
    # https://pip.pypa.io/en/stable/topics/local-project-installs/#editable-installs
    import warnings

    warnings.warn(
        "Importing __version__ failed. Using 'dev' as version.", stacklevel=2
    )
    __version__ = "dev"


__WALDIEZ_INITIALIZED = False

if not __WALDIEZ_INITIALIZED:
    __WALDIEZ_INITIALIZED = True
    check_conflicts()
    check_flaml_warnings()
    # let's skip the one below
    # check_pysqlite3()
    # and use it only if needed:
    #   captain_agent dependency:
    #   before calling pip install pyautogen[captainagent]
    #   we should have pysqlite3 installed (at least on windows)
    # before running a flow

__all__ = [
    "Waldiez",
    "WaldiezExporter",
    "WaldiezRunner",
    "__version__",
]
